<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="zh_TW" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>分類：</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>開始 torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>跳過雜湊值檢查</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>建立子資料夾</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent 管理模式：</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>所有</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>未分類</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>新增分類…</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>移除分類</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>移除未使用的分類</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>繼續 torrent</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>暫停 torrent</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>刪除 torrent</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新分類</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>編輯分類…</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>結束 qbittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>每行一連結</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>全域上傳速率限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>全域下載速率限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>替補的上傳速率限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>替補的下載速率限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>最大活躍下載數必須大於 -1。</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>最大活躍上傳數必須大於 -1。</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>最大活躍 torrent 數必須大於 -1。</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>最大連線數限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>每個 torrent 的最大下載者連線數限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>每個 torrent 上傳通道的最大數限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>無法儲存程式偏好設定，qBittorrent 可能無法連線。</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC：#qbittorrent 在 Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>分享速率限制必須在 0 到 9998 之間。</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>做種時間限制必須在 0 到 525600 分鐘之間。</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>連入的連線埠號必須在 1 到 65535 之間。</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web UI 使用的埠號必須在 1 到 65535 之間。</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>無法登入，qBittorrent 可能無法連線。</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>無效的使用者名稱或密碼。</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>原始作者</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>套用</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>上傳 torrent</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>儲存檔案到：</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie：</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>在這裡輸入資料夾</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>更多資訊</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>關於憑證的資訊</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>設定位置</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>限制上傳速率</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>限制下載速率</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>重新命名 torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>其他…</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期天</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>從他們的 URL 或磁力連結下載 torrent</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>上傳本機 torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>您確定要刪除在傳輸清單中選定的 torrent 嗎？</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>連接不到 qBittorrent 客戶端</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>全域上傳通道數量限制必須大於 0 或停用。</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>無效的分類名稱：\n分類名稱請不要使用任何特殊字元。</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>無法建立分類</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>上傳速率閾值必須大於 0。</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>可用空間：%1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrent 非活躍計時器必須大於 0。</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>存檔管理</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>下載速率閾值必須大於 0。</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent 已經關閉</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>選項…</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>最低優先度</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>最高優先度</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>減少優先度</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>增加優先度</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>頂端工具列</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>狀態列</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>在標題列的速率</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>捐款！</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>全部繼續</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計資料</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>全部暫停</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>新增 torrent 檔案…</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>說明文件</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>新增 torrent 連結</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>全域上傳速率限制</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>全域下載速率限制</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>您確定要退出 qBittorrent 嗎？</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[下載：%1，上傳：%2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>替補速率限制</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>搜尋引擎</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>過濾 torrent 清單…</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>傳輸</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>連線</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>使用者介面語言：</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>下載完成時使用電子郵件通知</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>當 torrent 下載完成時執行外部程式</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP 過濾</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>預約使用替補速率限制</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent 佇列</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>對 torrent 做種直到達到做種時間</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>自動新增這些追蹤者到新的下載中：</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web UI (遠端控制)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP 位置：</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>伺服器網域：</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>使用 HTTPS 而不是 HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>在本機上跳過客戶端驗證</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>在已在白名單中的 IP 子網跳過驗證</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>更新我的動態領域名稱</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>保留未完成的 torrent 於：</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>複製 torrent 檔案到：</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>複製已完成的 torrent 檔案到：</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>為所有檔案事先分配硬碟空間</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>在未完成檔案加上 .!qB 副檔名</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>自動載入 torrent 檔案：</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP 伺服器：</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>這個伺服器需要加密連線 (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>驗證</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>使用者名稱：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>已啟用協定：</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP 與 μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>監聽埠</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>連入連線時使用的埠：</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>使用從路由器轉送的 UPnP／NAT-PMP 連接埠</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>每次啟動時使用不同的埠</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>連線限制</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>每個 torrent 的最大連線數：</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>全域最大連線數：</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>每個 torrent 上傳通道的最大數：</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>全域的上傳通道最大數：</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>代理伺服器</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(無)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主機：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>埠：</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>使用代理伺服器來連線下載者</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>停用不被代理伺服器所支援的連線</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>只對 torrent 使用代理伺服器</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>過濾路徑 (.dat, .p2p, .p2b)：</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>手動封鎖 IP 位置…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>套用到追蹤者</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>全域速率限制</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>上傳：</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>下載：</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>替補速率限制</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>從：</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>到：</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>何時：</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>每天</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>平日</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>週末</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>速率限制設定</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>套用速率限制至傳輸負載</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>套用速率限制到 µTP 協定</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>隱私</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>啟用 DHT (分散式網路) 來尋找更多下載者</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>啟用下載者交換 (PeX) 來尋找更多下載者</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>啟用本地下載者搜尋來尋找更多下載者</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>加密模式：</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>偏好加密</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>要求加密</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>停用加密</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>啟用匿名模式</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>最大活躍的下載數：</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>最大活躍的上傳數：</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>最大活躍的 torrent 數：</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>在這些限制中不要計算速率慢的 torrent</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>分享率限制</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>對 torrent 做種直到達到分享率</translation>
    </message>
    <message>
        <source>then</source>
        <translation>然後</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>暫停它們</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>移除它們</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>使用 UPnP／NAT-PMP 轉送路由器連接埠</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>憑證：</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>鍵值：</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>註冊</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>網域名稱：</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>支援的參數 (區分大小寫)：</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N：Torrent 名稱</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L：分類</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G：標籤 (以逗號分隔)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F：內容路徑 (與多重 torrent 的根路徑相同)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R：根路徑 (第一個 torrent 的子目錄路徑)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D：儲存路徑</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C：檔案數</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z：Torrent 大小 (位元組)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T：目前的追蹤者</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I：資訊雜湊值</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>提示：把參數以引號包起來以避免被空格切斷 (例如："%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web UI 使用者名稱必須至少 3 字元長。</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web UI 密碼必須至少 6 字元長。</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>啟用點選劫持保護</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>啟用跨站請求偽造 (CSRF) 保護</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>事後刪除 .torrent 檔案</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>下載速率閾值：</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>上傳速率閾值：</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>變更目前的密碼</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>使用替補 Web UI</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>預設儲存路徑：</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>替補的 Web UI 檔案位置不應該為空白。</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>不要自動開始下載</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>切換 torrent 到手動模式</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>當 torrent 分類變更時：</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>重新定位受影響的 torrent</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>在 LAN 上套用對下載者的速率限制</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 代表無限制</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>重新定位 torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>當預設儲存路徑變更時：</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>啟用主機檔頭驗證</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>當分類儲存路徑變更：</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>為有多個檔案的 torrent 建立子資料夾</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>切換受影響的 torrent 至手動模式</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>檔案位置：</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrent 不活躍計時器：</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>預設 torrent 管理模式：</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>當增加 torrent 時</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>埠</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>旗標</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>連線</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>客戶端</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>進度</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下載速率</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上傳速率</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>已上傳</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>關聯</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>國籍</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>一般</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>高</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>最高</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>追蹤者</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>下載者</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP 來源</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>內容</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>已下載：</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>傳輸</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>經過時間：</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>預估剩餘時間：</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>已上傳：</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>種子：</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>下載速率：</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>上傳速率：</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>下載者：</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>下載限制：</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>上傳限制：</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>已丟棄：</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>連線：</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>註解：</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>分享率：</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>重新發佈於：</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>最後完整可見：</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>總大小：</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>分塊：</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>製作器：</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>增加於：</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>完成於：</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>建立於：</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent 雜湊值：</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>儲存路徑：</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (已完成 %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (今期 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (最大 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (總共 %2 個)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (平均 %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>下載限制：</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>上傳限制：</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>已監視的資料夾</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>覆寫儲存位置</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>已監視的資料夾</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>預設儲存位置</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>統計資料</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>使用者的統計資料</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>快取的統計資料</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>讀取快取次數：</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>在佇列的平均時間：</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>已連線的下載者：</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>合計總分享率：</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>合計總下載：</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>今期丟棄：</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>合計總上傳：</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>總緩衝大小：</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>效能統計</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>佇列的 I/O 任務：</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>寫入快取超過負荷：</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>讀取快取超過負荷：</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>總佇列大小：</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT：%1 個節點</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>全部 (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>下載中 (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>做種中 (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>已完成 (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>繼續 (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>暫停 (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>活躍的 (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>不活躍的 (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>錯誤 (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>全部 (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>下載中 (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>做種中 (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>已完成 (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>暫停 (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>繼續 (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>活躍的 (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>不活躍的 (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>錯誤 (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>進度</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>下載優先度</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>剩餘的</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>可得性</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>大小</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>完成</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>種子</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>下載者</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下載速率</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上傳速率</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>分享率</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>預估剩餘時間</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>標籤</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>增加於</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>完成於</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>追蹤者</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>下載限制</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>上傳限制</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>已上傳</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>今期下載</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>今期上傳</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>剩餘的</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>經過時間</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>儲存路徑</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>分享率限制</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>最後完整可見</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>最後活動</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>總大小</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>下載者</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>追蹤者 URL：</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>正在更新…</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>正在運作</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>尚未連線</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>種子</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>沒有運作</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>複製追蹤者 URL</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>新增追蹤者…</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>編輯追蹤者 URL…</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>編輯追蹤者</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>蝗族</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>移除追蹤者</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>增加追蹤者對話框</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>要增加的追蹤者清單 (每行一個)：</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 前</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>分配中</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>正在移動</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>強制做種</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>做種中</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>佇列</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>強制下載</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>正在下載中介資料</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>正在檢查</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>遺失的檔案</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>正等待檢查</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下載中</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>正在檢查復原資料</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>等待開始</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>分類</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent 下載速率限制</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent 上傳速率限制</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>強制繼續</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>限制分享率…</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>限制上傳速率…</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>限制下載速率…</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>向上移</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>向下移</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>移到最上面</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>移到最下面</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>設定位置…</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>複製名稱</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>複製雜湊值</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>先下載第一和最後一塊</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>自動 torrent 管理</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>新…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>重設</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>優先度</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>強制重新檢查</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>複製磁力連結</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>超級種子模式</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>重新命名…</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>依順序下載</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>強制重新檢查</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新分類</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>新名稱</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>設定位置</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>強制重新發佈</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>編輯分類</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>儲存路徑</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent 分享限制</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>使用全域分享限制</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>設定無分享限制</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>設定分享限制為</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>上傳╱下載比率</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分鐘</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>一個以 C++ 撰寫，基於 Qt 工具箱和 libtorrent-rasterbar 的進階 BitTorrent 客戶端。</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>首頁：</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>論壇：</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>遞交錯誤報告：</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>刪除確認</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>也把硬碟裡的檔案刪除</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>刪除確認 - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>從 URL 下載</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>增加 torrent 連結</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 小時 %2 分鐘</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 天 %2 小時</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>未知</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 分鐘</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 分鐘</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>儲存路徑為空白</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>外掛路徑：</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL 或本機目錄</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>安裝外掛</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>種子：</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>所有外掛</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>搜尋外掛…</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>所有分類</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>搜尋：</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>複製描述頁面的 URL</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>到描述頁</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>搜尋結果 (顯示</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>過濾器</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>僅 torrent 名稱</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>僅已啟用</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>中的</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>各處</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>解除安裝</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>安裝新的外掛</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>您可以在這裡取得新的搜尋引擎外掛：</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>已安裝的搜尋外掛：</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>已啟用</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>警告：請確保您從這些搜尋引擎中下載 torrent 時遵守您所在國家的版權法規。</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>搜尋外掛</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>下載者</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>搜尋引擎</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>種子</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>已啟用</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
</context>
</TS>